@@ -29,16 +29,12 @@
 #include "klog.h"
 
 
-static const char *description = I18N_NOOP("Klog");
+static const char *description = I18N_NOOP("The KDE Ham Radio Logging Software");
 
 
 // INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
 
 
-
-
-
-
 static KCmdLineOptions options[] =
         {
                 { 0, 0, 0 }
@@ -48,7 +44,7 @@ static KCmdLineOptions options[] =
 int main(int argc, char *argv[])
 {
 
-        KAboutData aboutData( "klog", I18N_NOOP("Klog"), "KLog-0.3.3", description, KAboutData::License_GPL,
+        KAboutData aboutData( "klog", I18N_NOOP("Klog"), "KLog-0.4", description, KAboutData::License_GPL,
                               "(c) 2002-2004, Jaime Robles, EA4TV", 0, "http://jaime.robles.nu", "jaime@kde.org");
         aboutData.addAuthor("Jaime Robles, EA4TV","http://jaime.robles.nu", "jaime@kde.org");
         KCmdLineArgs::init( argc, argv, &aboutData );
@@ -56,9 +52,17 @@ int main(int argc, char *argv[])
 
         KApplication a;
         Klog *klog = new Klog();
+//Comment
         if ((klog->haveWorld()) ) {
                 a.setMainWidget(klog);
                 klog->show();
                 return a.exec();
         }
+//Comment
+
+/*      klog->setCaption(a.makeStdCaption(i18n(description)));
+        a.setMainWidget(klog);
+        klog->show();
+        return a.exec();
+*/
 }
