@@ -247,6 +247,9 @@ QString Qso::getLocator() const {
 }
 
 void Qso::setIota(const QString &tiota){
+// TODO:
+// It is necessary to check the received QString to  allow only valid IOTA
+// references (CC-XXX)
   iota = tiota;
 }
 
@@ -325,18 +328,19 @@ void Qso::clearQso(){
   QDate qslRec;       // QSLRDATE
   
 */  
-qslRecc = 'N';      // QSL_RCVD Y, N, R, I
-qslSenc = 'N';      // QSL_SENT Y, N, R, I
-qslVia = "";     // QSL_VIA (C) //Manager
-qslInfo = ""; //;    // ADDRESS /QSLMSG
-comment = "";    // COMMENT
-//  int qslHow;         // How is the qsl to be send
-  manager = "";
-  gridSquare = "";
-  iota = "AF-0";   // GRIDSQUARE
-  callUsed = "";   // OPERATOR
-  name = "";       // NAME
-  qth = "";        // QTH
-  localAward = ""; // LocalAward
-
+	qslRecc = 'N';      // QSL_RCVD Y, N, R, I
+	qslSenc = 'N';      // QSL_SENT Y, N, R, I
+	qslVia = "";     // QSL_VIA (C) //Manager
+	qslInfo = ""; //;    // ADDRESS /QSLMSG
+	comment = "";    // COMMENT
+	//  int qslHow;         // How is the qsl to be send
+	manager = "";
+	gridSquare = "";
+	iota = "AF-0";   // GRIDSQUARE
+	callUsed = "";   // OPERATOR
+	name = "";       // NAME
+	qth = "";        // QTH
+	localAward = "0"; // LocalAward
+	localAwardNumber = 0; // Just for managing, not saved in the log
+	freq = "0.0"; // Frecuency
 }
