@@ -178,7 +178,7 @@ void World::create(){
 }
 
 QString World::getPrefix() const{
-    return prefix;   
+    return prefix;
 }
 
 
@@ -190,173 +190,151 @@ QString World::getPrefix() const{
 // "0" if we have not found it.
 
 int World::findEntity(const QString string){
-    
-    
-  // The first task is to isolate the prefix
+// If no Entity is found, we return "0"
 
-  prefixa = string;
-  prefixab = string;
-  prefix = "NULL";
-  qrz = prefixa;      // For last checks
-  qrz2 = qrz;
-  i = 0;
+// The first task is to isolate the prefix
 
-      
-  if(( (prefixa.contains('/')) || (prefixa.contains('\\')) )){
-      
-      i = giveEnt(prefixa); // Checking full "special prefixes" like "4U/OH2BBF" first
-      if (i!=0){
-//   prefix = prefixa;
-   return i;
-      }
-      
-    if (prefixa.contains('/')){
-      ij = prefixa.find('/');
-      if ( (abs)(ij) < (abs)((prefixa.length())- ij)  ) { //Like in F/EA4TV
-        prefixab = prefixa.left(ij);
-        qrz2 = prefixab;        
-      }else{// Like in EA4TV/F
-         if (!((prefixa.upper()).endsWith("/P"))
-            && (!(prefixa.upper()).endsWith("/B"))      
-            && !((prefixa.upper()).endsWith("/M"))
-            && (!(prefixa.upper()).endsWith("/QRP"))
-            && (!(prefixa.upper()).endsWith("/0"))
-            && (!(prefixa.upper()).endsWith("/1"))
-            && (!(prefixa.upper()).endsWith("/2"))
-            && (!(prefixa.upper()).endsWith("/3"))
-            && (!(prefixa.upper()).endsWith("/4"))
-            && (!(prefixa.upper()).endsWith("/5"))
-            && (!(prefixa.upper()).endsWith("/6"))
-            && (!(prefixa.upper()).endsWith("/7"))
-            && (!(prefixa.upper()).endsWith("/8"))
-            && (!(prefixa.upper()).endsWith("/9")))
-        {
-     // It is necessary to check for special prefixes like /r = Rotuma or /a = Mount Athos...
-     // So let's go  
-      if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("3D2" )) ){
-   // This is Conway Reef
-          prefixa = "3D2AM";              
-                 return giveEnt(prefixa);
-      }
-            if ( (prefixa.upper().endsWith("/R")) && (prefixa.upper().startsWith("3D2" )) ){
-            // This is Rotuma
-  prefixa = "3D2AA";              
-  return giveEnt(prefixa);
-            }     
-     
-            if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("3Y" )) ){
-            // This is Bouvet
-  prefixa = "3Y";
-  return giveEnt(prefixa);
-            }
-      
-            if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("FK" )) ){
-            // This is Chesterfield Is.
-  prefixa = "TX0AT";
-  return giveEnt(prefixa);
-            }
-      
-            if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("FO" )) ){
-            // This is Austral Is.
-  prefixa = "FO/HG9B";
-  return giveEnt(prefixa);
-            }
-      
-            if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("FO" )) ){
-            // This is Clipperton Is.
-  prefixa = "FO0AAA";
-  return giveEnt(prefixa);
-            }
-                  
-            if ( (prefixa.upper().endsWith("/G")) && (prefixa.upper().startsWith("FR" )) ){
-            // This is Glorioso Is.
-  prefixa = "FR/G";
-  return giveEnt(prefixa);
-            }
-     
-            if ( (prefixa.upper().endsWith("/J")) && (prefixa.upper().startsWith("FR" )) ){
-            // This is Juan de Nova & Europa Is.
-  prefixa = "FR4FA";
-  return giveEnt(prefixa);
-            }     
-     
-            if ( (prefixa.upper().endsWith("/T")) && (prefixa.upper().startsWith("FR" )) ){
-            // This is Tromelin Is.
-  prefixa = "FR/T";
-  return giveEnt(prefixa);
-            }          
-     
-            if ( (prefixa.upper().endsWith("/S")) && (prefixa.upper().startsWith("GM" )) ){
-            // This is Shetland Is.
-  prefixa = "2M1ANT";
-  return giveEnt(prefixa);
-            }          
-     
-            if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("HK0" )) ){
-            // This is San Andres/Providencia Is.
-  prefixa = "HK0";
-  return giveEnt(prefixa);
-            }          
-     
-            if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("HK0" )) ){
-            // This is Malpelo Is.
-  prefixa = "5J0M";
-  return giveEnt(prefixa);
-            }          
-     
-            if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("JD" )) ){
-            // This is Minami Torishima Is.
-  prefixa = "7J1ACH";
-  return giveEnt(prefixa);
-            }          
-     
-            if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("JD" )) ){
-            // This is Ogasawara Is.
-  prefixa = "7J1ATZ";
-  return giveEnt(prefixa);
-            }          
-     
-            if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("JW" )) ){
-            // This is Bear Is.
-  prefixa = "JW2FL";
-  return giveEnt(prefixa);
-            }         
-     
-            if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("SV" )) ){
-            // This is Mount Athos Is.
-  prefixa = "SY2A";
-  return giveEnt(prefixa);
-            }         
-     
-            if ( (prefixa.upper().endsWith("/D")) && (prefixa.upper().startsWith("VP6" )) ){
-            // This is Ducie Is.
-  prefixa = "VP6DI";
-  return giveEnt(prefixa);
-            }         
-     
-            if ( (prefixa.upper().endsWith("/G")) && (prefixa.upper().startsWith("VP8" )) ){
-            // This is South Georgia Is.
-  prefixa = "VP8BUB";
-  return giveEnt(prefixa);
-            }         
-     
-            if ( (prefixa.upper().endsWith("/H")) && (prefixa.upper().startsWith("VP8" )) ){
-            // This is South Shetland Is.
-  prefixa = "4K1ADQ";
-  return giveEnt(prefixa);
-            }         
-     
-            if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("VP8" )) ){
-            // This is South Orkney Is.
-  prefixa = "AY1ZA";
-  return giveEnt(prefixa);
-            }         
-     
-            if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("VP8" )) ){
-            // This is South Sandwich Is.
-  prefixa = "4K1ZI";
-  return giveEnt(prefixa);
-            }         
+	prefixa = string;
+	prefixab = string;
+	prefix = "NULL";
+	qrz = prefixa;      // For last checks
+	qrz2 = qrz;
+	i = 0;
+
+	if(( (prefixa.contains('/')) || (prefixa.contains('\\')) )){
+		i = giveEnt(prefixa); // Checking full "special prefixes" like "4U/OH2BBF" first
+		if (i!=0){
+			//   prefix = prefixa;
+			return i;
+		}
+		if (prefixa.contains('/')){
+			ij = prefixa.find('/');
+			if ( (abs)(ij) < (abs)((prefixa.length())- ij)  ) { //Like in F/EA4TV
+				prefixab = prefixa.left(ij);
+				qrz2 = prefixab;
+			}else{// Like in EA4TV/F
+				if (!((prefixa.upper()).endsWith("/P"))	// Portable
+				&& (!(prefixa.upper()).endsWith("/B"))	// Beacon
+				&& !((prefixa.upper()).endsWith("/M"))	//Mobile
+				&& !((prefixa.upper()).endsWith("/MM"))  // Maritime mobile
+				&& (!(prefixa.upper()).endsWith("/QRP"))
+				&& (!(prefixa.upper()).endsWith("/0"))
+				&& (!(prefixa.upper()).endsWith("/1"))
+				&& (!(prefixa.upper()).endsWith("/2"))
+				&& (!(prefixa.upper()).endsWith("/3"))
+				&& (!(prefixa.upper()).endsWith("/4"))
+				&& (!(prefixa.upper()).endsWith("/5"))
+				&& (!(prefixa.upper()).endsWith("/6"))
+				&& (!(prefixa.upper()).endsWith("/7"))
+				&& (!(prefixa.upper()).endsWith("/8"))
+				&& (!(prefixa.upper()).endsWith("/9"))){
+			// It is necessary to check for special prefixes like /r = Rotuma or /a = Mount Athos...
+			// So let's go  
+					if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("3D2" )) ){
+					// This is Conway Reef
+						prefixa = "3D2AM";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/R")) && (prefixa.upper().startsWith("3D2" )) ){
+					// This is Rotuma
+						prefixa = "3D2AA";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("3Y" )) ){
+					// This is Bouvet
+						prefixa = "3Y";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("FK" )) ){
+					// This is Chesterfield Is.
+						prefixa = "TX0AT";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("FO" )) ){
+					// This is Austral Is.
+						prefixa = "FO/HG9B";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("FO" )) ){
+					// This is Clipperton Is.
+						prefixa = "FO0AAA";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/G")) && (prefixa.upper().startsWith("FR" )) ){
+					// This is Glorioso Is.
+						prefixa = "FR/G";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/J")) && (prefixa.upper().startsWith("FR" )) ){
+					// This is Juan de Nova & Europa Is.
+						prefixa = "FR4FA";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/T")) && (prefixa.upper().startsWith("FR" )) ){
+					// This is Tromelin Is.
+						prefixa = "FR/T";
+						return giveEnt(prefixa);
+            				}
+					if ( (prefixa.upper().endsWith("/S")) && (prefixa.upper().startsWith("GM" )) ){
+					// This is Shetland Is.
+						prefixa = "2M1ANT";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("HK0" )) ){
+					// This is San Andres/Providencia Is.
+						prefixa = "HK0";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("HK0" )) ){
+					// This is Malpelo Is.
+						prefixa = "5J0M";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("JD" )) ){
+					// This is Minami Torishima Is.
+						prefixa = "7J1ACH";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("JD" )) ){
+					// This is Ogasawara Is.
+						prefixa = "7J1ATZ";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("JW" )) ){
+					// This is Bear Is.
+						prefixa = "JW2FL";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/A")) && (prefixa.upper().startsWith("SV" )) ){
+					// This is Mount Athos Is.
+						prefixa = "SY2A";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/D")) && (prefixa.upper().startsWith("VP6" )) ){
+					// This is Ducie Is.
+						prefixa = "VP6DI";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/G")) && (prefixa.upper().startsWith("VP8" )) ){
+					// This is South Georgia Is.
+						prefixa = "VP8BUB";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/H")) && (prefixa.upper().startsWith("VP8" )) ){
+					// This is South Shetland Is.
+						prefixa = "4K1ADQ";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("VP8" )) ){
+					// This is South Orkney Is.
+						prefixa = "AY1ZA";
+						return giveEnt(prefixa);
+					}
+					if ( (prefixa.upper().endsWith("/O")) && (prefixa.upper().startsWith("VP8" )) ){
+					// This is South Sandwich Is.
+						prefixa = "4K1ZI";
+						return giveEnt(prefixa);
+					}
      
             if ( (prefixa.upper().endsWith("/N")) && (prefixa.upper().startsWith("ZK1" )) ){
             // This is North Cook Is.
